@@ -25,6 +25,11 @@
 #if !defined(__APPLE__)
 #include <malloc.h>
 #endif
+#if defined(__APPLE__)
+#if (__APPLE_CC__<5658)
+#include <malloc.h>
+#endif
+#endif
 #include "Framework.h"
 
 // //RankSwapping
@@ -55,4 +60,6 @@ enum{
 
 #include "Measure_Threshold.h"
 
+#include "LocalRecProg/kneibmatch.cpp"
+
 
